@@ -7,5 +7,9 @@ from ._flatten_lists import _flatten_list_of_lists as flatten
 # from ._zero_centered_random import _zero_centered_random as zero_centered_random
 from ._pystrings import _format_string_printing_font as format_pystring
 from ._search_and_destroy import _find_and_destroy_pycache as findNdestroy_pycache
+from ._pyGSUTILS_module._pyGSUTILS import _pyGSUTILS as pyGSUTILS
 
-from ._pyGSUTILS_module._pyGSUTILS import _pyGSUTILS as pyGSUTILS
\ No newline at end of file
+from ._dynamical_import_of_function_from_string import _dynamical_import_of_function_from_string as import_from_string
+from ._deinterleaf import _deinterleaf_fastq as deinterleaf_fastq
+from ._report_imports import _report_imports as imports
+from ._get_vintools_version import _get_vintools_version as version
